## Datasets

One of main goals of **covirus** is provide ready-to-use [Datasets](https://github.com/maricatovictor/covirus/blob/master/covirus/data/dataset.py)

## Currently Available Datasets

| country | source | Description | Objects
|--|--|--|--|
| `BR`  | `wcota`  | Casos e óbitos confirmados por dia, utilizando informação oficial pelo  [Ministério da Saúde](https://covid.saude.gov.br/), dados no nível municipal do  [Brasil.IO](https://brasil.io/dataset/covid19/caso)  e dados mais recentes reportados pela equipe do  [@CoronavirusBra1](https://twitter.com/CoronavirusBra1). Mais informações:  [https://wcota.me/covid19br](https://wcota.me/covid19br) | cities, cities_time, states, total